Stan Math Library: stan/math/prim/mat/fun/variance.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
variance.hpp File Reference
`#include <stan/math/prim/arr/err/check_nonzero_size.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/mean.hpp>`
`#include <boost/math/tools/promotion.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
boost::math::tools::promote_args< T >::type | stan::math::variance (const std::vector< T > &v)
| Returns the sample variance (divide by length - 1) of the coefficients in the specified standard vector. More...
template<typename T , int R, int C>
boost::math::tools::promote_args< T >::type | stan::math::variance (const Eigen::Matrix< T, R, C > &m)
| Returns the sample variance (divide by length - 1) of the coefficients in the specified column vector. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.